goodman\_focus package
======================

Subpackages
-----------

.. toctree::

    goodman_focus.tests

Submodules
----------

goodman\_focus.goodman\_focus module
------------------------------------

.. automodule:: goodman_focus.goodman_focus
    :members:
    :undoc-members:
    :show-inheritance:

goodman\_focus.version module
-----------------------------

.. automodule:: goodman_focus.version
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: goodman_focus
    :members:
    :undoc-members:
    :show-inheritance:
